#include <avr/io.h>
#define F_CPU 16000000
#include <util/delay.h>
#include <stdio.h>

int uart_putchar(char c, FILE *unused)      
{
	if (c == '\n') uart_putchar('\r', 0);
	loop_until_bit_is_set(UCSRA, UDRE);
	UDR = c;
	return 0;
}

int uart_getchar(FILE* f)
{
	char c;
  	loop_until_bit_is_set(UCSRA, RXC);
  	c = UDR;
  	if(c=='\r')
	c='\n';
  	return c;
}
void EEPROM_write(unsigned int uiAddress, unsigned char ucData)
{
	/* Wait for completion of previous write */
	while(EECR & (1<<EEWE));
	/* Set up address and data registers */
	EEAR = uiAddress;
	EEDR = ucData;
	/* Write logical one to EEMWE */
	EECR |= (1<<EEMWE);
	/* Start eeprom write by setting EEWE */
	EECR |= (1<<EEWE);
}

unsigned char EEPROM_read(unsigned int uiAddress)
{
	/* Wait for completion of previous write */
	while(EECR & (1<<EEWE));
	/* Set up address register */
	EEAR = uiAddress;
	/* Start eeprom read by writing EERE */
	EECR |= (1<<EERE);
	/* Return data from data register */
	return EEDR;
}

#define sus 'w'
#define jos 's'
#define stanga 'a'
#define dreapta 'd'
#define start 'r'
#define stop 't'
#define replay 'p'

#define PIN_DREAPTA PA2
#define PIN_STANGA PA3
#define PIN_SUS PA1
#define PIN_JOS PA0

void USART_init(void)
{
	//TODO
	// Initializare modul USART pt comunicatie la 9600bps, 8 biti de date, la 16MHz										
	const int ubbr = 103;

	UBRRH = (unsigned char) (ubbr >> 8);
	UBRRL = (unsigned char) (ubbr);
	UCSRB = (1 << RXEN) | (1 << TXEN);
	UCSRC = (1 << URSEL) | (3 << UCSZ0);
	
}

FILE mystdout = FDEV_SETUP_STREAM(uart_putchar, NULL, _FDEV_SETUP_WRITE);
FILE mystdin = FDEV_SETUP_STREAM(NULL, uart_getchar, _FDEV_SETUP_READ);

int main()
{

int inregistrare = 0;
int salvez = 0;
int final = 0;
int f=1;
int i;
char c;
char message;

stdout =  &mystdout;
stdin = &mystdin;

USART_init();

DDRA = 0XFF;

//Astept un mesaj si apoi intorc comanda data
for(;;)
{
	PORTA = 0;                         
	scanf("%c",&message);   
	
	switch((int)message)
	{
		case ((int)stanga):
			printf("stanga\n");
			PORTA = _BV(PIN_STANGA);
			if(f) PORTA |= _BV(PIN_SUS);
			else PORTA |= _BV(PIN_JOS);
			break;
		case ((int)dreapta):
			printf("dreapta\n");
			PORTA = _BV(PIN_DREAPTA);
			if(f) PORTA |= _BV(PIN_SUS);
			else PORTA |= _BV(PIN_JOS);
			break;
		case ((int)sus):
			printf("sus\n");
			PORTA = _BV(PIN_SUS);
			f = 1;
			break;
		case ((int)jos):
			printf("jos\n");
			PORTA = _BV(PIN_JOS);
			f = 0;
			break;	
		case((int)start):
			printf("salvez\n");
			salvez = 1;
			break;
		case((int)stop):
			printf("nu mai salvez\n");
			salvez = 0;
			final = inregistrare;
			inregistrare = 0;
			break;
		case((int)replay):
			printf("replay\n");
			f=1;
			for(i=0;i<final;i++)
			{
				if ((int)c==(int)stanga) PORTA |= _BV(PIN_STANGA);    // acelasi lucru ca atunci cand primeste comenzile de la tastatura dar
				else if ((int)c==(int)dreapta) PORTA |= _BV(PIN_DREAPTA); // acum le citeste din memorie
				c = EEPROM_read(i);
				
				switch((int)c)
				{
					case ((int)stanga):
						printf("stanga\n");
						PORTA = _BV(PIN_STANGA);
						if(f) PORTA |= _BV(PIN_SUS);
						else PORTA |= _BV(PIN_JOS);
						break;
					case ((int)dreapta):
						printf("dreapta\n");
						PORTA = _BV(PIN_DREAPTA);
						if(f) PORTA |= _BV(PIN_SUS);
						else PORTA |= _BV(PIN_JOS);
						break;
					case ((int)sus):
						printf("sus\n");
						PORTA = _BV(PIN_SUS);
						f=1;
						break;
					case ((int)jos):
						printf("jos\n");
						PORTA = _BV(PIN_JOS);
						f=0;
						break;	
				}
				_delay_ms(200);
			}
			break;
	}
	if (salvez == 1)
	{
		EEPROM_write(inregistrare,message); // salvez datele cu EEPROM
		inregistrare++;
	}
	_delay_ms(200);
}
  	return 0;
}